@@ -38,35 +38,34 @@ get.ArAr.age <- function(Ar40Ar39,sAr40Ar39,J,sJ,exterr=TRUE){
 
 # x an object of class \code{ArAr} returns a matrix 
 # of 40Ar/39Ar-ages and their uncertainties.
-ArAr.age <- function(x,exterr=TRUE,i=NA,sigdig=NA,i2i=FALSE,omit4c=NULL){
+ArAr.age <- function(x,exterr=TRUE,i=NA,sigdig=NA,
+                     i2i=FALSE,projerr=FALSE,omit4c=NULL){
     ns <- length(x)
     if (ns<2) i2i <- FALSE
     out <- matrix(0,ns,2)
     colnames(out) <- c('t','s[t]')
-    y <- data2york(x,inverse=TRUE)
     if (i2i){
+        y <- data2york(x,inverse=TRUE)
         fit <- york(clear(y,omit4c))
-        b <- fit$b[1]
+        b <- fit$b
+        DP <- 1/(y[,'X'] - y[,'Y']/b[1])
+        J1 <- -DP^2
+        J2 <- (DP^2)/b[1]
+        J3 <- -y[,'Y']*(DP/b[1])^2
+        E33 <- rep(b[2]^2,ns)
     } else {
-        atm <- iratio("Ar40Ar36")[1]
-        b <- (y[,'Y']-1/atm)/y[,'X']
+        y <- data2york(x,inverse=FALSE)
+        a <- iratio("Ar40Ar36")
+        DP <- (y[,'Y']-a[1])/y[,'X']
+        J1 <- -DP/y[,'X']
+        J2 <- 1/y[,'X']
+        J3 <- -1/y[,'X']
+        E33 <- rep(a[2]^2,ns)
     }
-    DP <- 1/(y[,'X'] - y[,'Y']/b)
     E11 <- y[,'sX']^2
     E22 <- y[,'sY']^2
     E12 <- y[,'rXY']*y[,'sX']*y[,'sY']
-    if (i2i){
-        J1 <- -DP^2
-        J2 <- (DP^2)/b
-        J3 <- -y[,'Y']*DP^2
-        E33 <- rep(fit$b[2]^2,ns)
-    } else {
-        J1 <- -DP/y[,'X']
-        J2 <- -atm/y[,'X']
-        J3 <- -y[,'Y']/y[,'X']
-        E33 <- rep(iratio("Ar40Ar36")[2]^2,ns)
-    }
-    if (exterr) sDP <- errorprop1x3(J1,J2,J3,E11,E22,E33,E12)
+    if (projerr) sDP <- errorprop1x3(J1,J2,J3,E11,E22,E33,E12)
     else sDP <- errorprop1x2(J1,J2,E11,E22,E12)
     tt <- get.ArAr.age(DP,sDP,x$J[1],x$J[2],exterr=exterr)
     out <- roundit(tt[,1],tt[,2],sigdig=sigdig)
