@@ -124,15 +124,15 @@ scatterplot <- function(xy,alpha=0.05,show.numbers=FALSE,
                         empty=FALSE, ci.col='gray80',line.col='black',
                         lwd=1,hide=NULL,omit=NULL,omit.fill=NA,
                         omit.stroke="grey",addcolourbar=TRUE,
-                        bg,cex,xlim,ylim,xlab,ylab,...){
+                        bg,cex,xlim=NULL,ylim=NULL,xlab,ylab,...){
     ns <- nrow(xy)
     if (ncol(xy)==4) xy <- cbind(xy,rep(0,ns))
     sn <- 1:ns
     plotit <- sn%ni%hide
     calcit <- sn%ni%c(hide,omit)
     colnames(xy) <- c('X','sX','Y','sY','rXY')
-    if (missing(xlim)) xlim <- get.limits(xy[plotit,'X'],xy[plotit,'sX'])
-    if (missing(ylim)) ylim <- get.limits(xy[plotit,'Y'],xy[plotit,'sY'])
+    if (is.null(xlim)) xlim <- get.limits(xy[plotit,'X'],xy[plotit,'sX'])
+    if (is.null(ylim)) ylim <- get.limits(xy[plotit,'Y'],xy[plotit,'sY'])
     if (!add){
         if (missing(xlab)) xlab <- ''
         if (missing(ylab)) ylab <- ''
@@ -178,12 +178,10 @@ scatterplot <- function(xy,alpha=0.05,show.numbers=FALSE,
         dy <- fact*xy[plotit,'sY']
         graphics::arrows(xy[plotit,'X'],xy[plotit,'Y']-dy,
                          xy[plotit,'X'],xy[plotit,'Y']+dy,
-                         code=3,angle=90,
-                         length=0.05,col=stroke)
+                         code=3,angle=90,length=0.05,col=stroke)
         graphics::arrows(xy[plotit,'X']-dx,xy[plotit,'Y'],
                          xy[plotit,'X']+dx,xy[plotit,'Y'],
-                         code=3,angle=90,
-                         length=0.05,col=stroke)
+                         code=3,angle=90,length=0.05,col=stroke)
     }
     if (!nolevels & addcolourbar){
         colourbar(z=levels[calcit],fill=ellipse.fill,
